import apipkg

# Implement lazy loading
apipkg.initpkg(__name__, {
    'BaseIndex': 'muzlin.index.base:BaseIndex',
    'LangchainIndex': 'muzlin.index.langchain:LangchainIndex',
    'LlamaIndex': 'muzlin.index.llama_index:LlamaIndex',
})



import apipkg

# Implement lazy loading
apipkg.initpkg(__name__, {
    'BaseEncoder': 'muzlin.encoders.base:BaseEncoder',
    'AzureOpenAIEncoder': 'muzlin.encoders.zure:AzureOpenAIEncoder',
    'BedrockEncoder': 'muzlin.encoders.bedrock:BedrockEncoder',
    'CohereEncoder': 'muzlin.encoders.cohere:CohereEncoder',
    'FastEmbedEncoder': 'muzlin.encoders.fastembed:FastEmbedEncoder',
    'GoogleEncoder': 'muzlin.encoders.google:GoogleEncoder',
    'HuggingFaceEncoder': 'muzlin.encoders.huggingface:HuggingFaceEncoder',
    'HFEndpointEncoder': 'muzlin.encoders.huggingface:HFEndpointEncoder',
    'VoyageAIEncoder': 'muzlin.encoders.voyageai:VoyageAIEncoder',
    'MistralEncoder': 'muzlin.encoders.mistral:MistralEncoder',
    'OpenAIEncoder': 'muzlin.encoders.openai:OpenAIEncoder',
})



import apipkg

# Implement lazy loading
apipkg.initpkg(__name__, {
    'OutlierCluster': 'muzlin.anomaly.cluster:OutlierCluster',
    'OutlierDetector': 'muzlin.anomaly.detector:OutlierDetector',
    'GraphOutlierDetector': 'muzlin.anomaly.graph:GraphOutlierDetector',
    'optimize_threshold': 'muzlin.anomaly.utils:optimize_threshold',
})
